@@ -135,16 +135,10 @@ class OneParamFunction(FormulaCommand):
     self.output = TaggedOutput().settag(self.functions[command])
     self.parseparameter(pos)
 
-class LabelFunction(FormulaCommand):
-  "A function that acts as a label"
+class LiteralFunction(OneParamFunction):
+  "A function where parameters are read literally"
 
-  functions = FormulaConfig.labelfunctions
-
-  def detect(self, pos):
-    "Detect the start of the function"
-    if self.findcommand(pos, self.functions):
-      return True
-    return False
+  functions = FormulaConfig.literalfunctions
 
   def parse(self, pos):
     "Parse a literal parameter"
@@ -154,6 +148,21 @@ class LabelFunction(FormulaCommand):
     bracket = Bracket().parseliteral(pos)
     self.add(bracket)
 
+  def process(self):
+    "Move the bracket contents to a constant"
+    self.type = 'font'
+    text = self.contents[0].contents
+    self.contents = [FormulaConstant(text)]
+
+class LabelFunction(LiteralFunction):
+  "A function that acts as a label"
+
+  functions = FormulaConfig.labelfunctions
+
+  def process(self):
+    "Do not process the inside"
+    self.type = 'font'
+
 class FontFunction(OneParamFunction):
   "A function of one parameter that changes the font"
 
@@ -184,6 +193,34 @@ class DecoratingFunction(OneParamFunction):
       self.output = FixedOutput()
       self.html = [FormulaConfig.alphacommands[self.original]]
 
+class HybridFunction(FormulaCommand):
+  "Read a function with two parameters: [] and {}"
+
+  def detect(self, pos):
+    "Detect the start of the function"
+    if self.findcommand(pos, FormulaConfig.hybridfunctions):
+      return True
+    return False
+
+  def parse(self, pos):
+    "Parse a function with [] and {} parameters"
+    command = self.findcommand(pos, FormulaConfig.hybridfunctions)
+    self.addoriginal(command, pos)
+    self.parsemagnitude(pos)
+    unit = FormulaConstant(Bracket().parseliteral(pos).contents)
+    unit.type = 'font'
+    self.contents[0].add(unit)
+
+  def parsemagnitude(self, pos):
+    "Parse the magnitude bit"
+    magnitude = SquareBracket().parseliteral(pos).contents
+    Trace.debug('Magnitude: ' + magnitude)
+    newpos = Position(magnitude)
+    whole = WholeFormula()
+    whole.parse(newpos)
+    whole.process()
+    self.contents = [whole]
+
 class FractionFunction(FormulaCommand):
   "A fraction with two parameters"
 
@@ -228,7 +265,8 @@ class UnknownCommand(FormulaCommand):
 
 FormulaFactory.bits += [
     EmptyCommand(), OneParamFunction(), DecoratingFunction(),
-    FractionFunction(), FontFunction(), LabelFunction(),
+    FractionFunction(), FontFunction(), LabelFunction(), LiteralFunction(),
+    HybridFunction(),
     ]
 
 FormulaFactory.unknownbits += [ UnknownCommand() ]
