@@ -50,9 +50,6 @@ class PostLayout(object):
 
   processedclass = Layout
 
-  ordered = ['Chapter', 'Section', 'Subsection', 'Subsubsection', 'Paragraph']
-  unique = ['Part', 'Book']
-
   def __init__(self):
     self.generator = NumberGenerator.instance
 
@@ -60,13 +57,14 @@ class PostLayout(object):
     "Generate a number and place it before the text"
     if self.containsappendix(layout):
       self.activateappendix()
-    if layout.type in PostLayout.unique:
+    if layout.type in NumberingConfig.unique:
       number = self.generator.generateunique(layout.type)
-    elif layout.type in PostLayout.ordered:
-      level = PostLayout.ordered.index(layout.type)
+    elif layout.type in NumberingConfig.ordered:
+      level = NumberingConfig.ordered.index(layout.type)
       number = self.generator.generate(level)
     else:
       return layout
+    layout.number = number
     layout.contents.insert(0, Constant(number + u' '))
     return layout
 
